/**
 * create this file at 下午1:22:51 by renhd.
 */
package com.allinpay.yst2.demo.tx;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.annotation.JSONField;
import com.alibaba.fastjson.serializer.SerializeConfig;
import com.alibaba.fastjson.serializer.ValueFilter;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.springframework.util.StringUtils;

import javax.validation.constraints.NotBlank;
import java.io.Serializable;

/**
 * @author 任海东
 * @since 2024年6月12日
 */
@Data
@ApiModel("请求参数说明")
public class ApiReq implements Serializable {

	private static final long serialVersionUID = 1L;

	@NotBlank(message = "appId不能为空")
	@ApiModelProperty(value = "云商通二代分配的应用ID", required = true)
	private String appId;

	@ApiModelProperty(value = "云商通二代分配的服务商应用ID")
	private String spAppId;

	@NotBlank(message = "transCode不能为空")
	@ApiModelProperty(value = "接口代码", required = true)
	private String transCode;

	@ApiModelProperty(value = "仅支持JSON", allowableValues = "json")
	private String format;

	@ApiModelProperty(value = "请求使用的编码格式", allowableValues = "UTF-8", required = true)
	private String charset;

	@ApiModelProperty(value = "签名方式", allowableValues = "SM3withSM2", required = true)
	@JSONField(serialize = false)
	private String signType;

	@NotBlank(message = "sign不能为空")
	@ApiModelProperty(value = "签名，签名规则：剔除sign和signType字段，剔除值为空的参数，并按照键值ASCII码递增排序，"
			+ "组合成“参数=参数值”的格式，并且把这些参数用&字符连接起来，拼接成签名源串", required = true)
	@JSONField(serialize = false)
	private String sign;

	@NotBlank(message = "transDate不能为空")
	@ApiModelProperty(value = "发送请求的日期,格式yyyyMMdd", required = true)
	private String transDate;

	@NotBlank(message = "transTime不能为空")
	@ApiModelProperty(value = "发送请求的时间,格式HHmmss", required = true)
	private String transTime;

	@ApiModelProperty(value = "版本号", required = true, allowableValues = "1.0")
	private String version;

	@NotBlank(message = "bizData不能为空")
	@ApiModelProperty(value = "业务参数，json格式字符串，具体详见业务接口说明文档", required = true)
	private String bizData;

	public String toJSONString() {
		final SerializeConfig serializeConfig = new SerializeConfig();
		serializeConfig.addFilter(getClass(), (ValueFilter) (object, name,
				value) -> value == null || !StringUtils.hasText(value.toString()) ? null : value);
		return JSON.toJSONString(this, serializeConfig);
	}

}
